@@ -53,7 +53,7 @@
 #include <KServiceTypeTrader>
 #include <KWindowSystem>
 #include <KIconLoader>
-#include <KWallet/Wallet>
+#include <KWallet>
 
 #define AGENT_SERVICE "org.kde.kded5"
 #define AGENT_PATH "/modules/networkmanagement"
@@ -434,7 +434,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
 {
     QDBusPendingReply<> reply = *watcher;
     if (reply.isError() || !reply.isValid()) {
-        KNotification *notification = 0;
+        KNotification *notification = nullptr;
         QString error = reply.error().message();
         Handler::HandlerAction action = (Handler::HandlerAction)watcher->property("action").toUInt();
         switch (action) {
@@ -479,7 +479,7 @@ void Handler::replyFinished(QDBusPendingCallWatcher * watcher)
             notification->sendEvent();
         }
     } else {
-        KNotification *notification = 0;
+        KNotification *notification = nullptr;
         Handler::HandlerAction action = (Handler::HandlerAction)watcher->property("action").toUInt();
 
         switch (action) {
